##  Exporting Workspace Data
The following export options are available:
  * Full Snapshot: Full snapshot of the workspace data that includes information from all active fact sheets, as well as information about related objects such as relations, tag groups, tags, resources (also referred to as documents), and comments. The snapshot doesn't include archived fact sheets.
  * Changelog: Data-related changes made to the workspace within a specified timeframe. The default timeframe is 30 days. On the fact sheet details page, the changelog appears on the Last Update tab.
  * Archive: Full snapshot of the archived workspace data that includes information from all archived fact sheets, as well as information about related objects such as relations, tag groups, tags, resources (also referred to as documents), and comments. You can use this export option to view archived fact sheets before they are deleted at the end of the retention period. For more information, see [Archiving, Deleting and Recovering Fact Sheets](https://help.sap.com/docs/leanix/ea/archiving-deleting-and-recovering-fact-sheets?locale=en-US&state=PRODUCTION&version=CLOUD "Learn to archive fact sheets individually or in bulk and effortlessly view or recover archived fact sheets in SAP LeanIX.").


**Note**
If your organization uses security email checkers, they might delete export snapshots before you open the email with the download link. To avoid this, stay on the export page in your workspace and wait for the file to download directly through your browser.
